<div align="center">

<a href="https://v2.nonebot.dev/store">
  <img src="https://raw.githubusercontent.com/A-kirami/nonebot-plugin-template/resources/nbp_logo.png" width="180" height="180" alt="NoneBotPluginLogo">
</a>

<p>
  <img src="https://raw.githubusercontent.com/A-kirami/nonebot-plugin-template/resources/NoneBotPlugin.svg" width="240" alt="NoneBotPluginText">
</p>

# NoneBot-Plugin-Groupmate-WAIFU

娶群友

[![python](https://img.shields.io/badge/python-3.12+-blue.svg)](https://www.python.org/)
[![Poetry](https://img.shields.io/endpoint?url=https://python-poetry.org/badge/v0.json)](https://python-poetry.org/)
[![license](https://img.shields.io/github/license/KarisAya/nonebot_plugin_groupmate_waifu.svg)](./LICENSE)
[![pypi](https://img.shields.io/pypi/v/nonebot_plugin_groupmate_waifu.svg)](https://pypi.python.org/pypi/nonebot_plugin_groupmate_waifu)
[![pypi download](https://img.shields.io/pypi/dm/nonebot_plugin_groupmate_waifu)](https://pypi.python.org/pypi/nonebot_plugin_groupmate_waifu)
<br />

[![机器人 bug 研究中心](https://img.shields.io/badge/QQ%E7%BE%A4-744751179-maroon?)](https://qm.qq.com/q/3vpD9Ypb0c)

</div>

# 💿 安装

以下提到的方法 任选**其一** 即可

<details open>
<summary>[推荐] 使用 nb-cli 安装</summary>
在 nonebot2 项目的根目录下打开命令行, 输入以下指令即可安装

```bash
nb plugin install nonebot_plugin_groupmate_waifu
```

</details>

<details>
<summary>使用包管理器安装</summary>
在 nonebot2 项目的插件目录下, 打开命令行, 根据你使用的包管理器, 输入相应的安装命令

<details>
<summary>pip</summary>

```bash
pip install nonebot_plugin_groupmate_waifu
```

</details>
<details>
<summary>pdm</summary>

```bash
pdm add nonebot_plugin_groupmate_waifu
```

</details>
<details>
<summary>poetry</summary>

```bash
poetry add nonebot_plugin_groupmate_waifu
```

</details>
<details>
<summary>conda</summary>

```bash
conda install nonebot_plugin_groupmate_waifu
```

</details>

打开 nonebot2 项目根目录下的 `pyproject.toml` 文件, 在 `[tool.nonebot]` 部分的 `plugins` 项里追加写入

```toml
[tool.nonebot]
plugins = [
    # ...
    "nonebot_plugin_game_collection"
]
```

</details>

# 配置

# 使用文档

具体配置方法请参考[clovers_groupmate_waifu](https://github.com/KarisAya/clovers_groupmate_waifu)

```env
NONEBOT_PLUGIN_GROUPMATE_WAIFU_FONTNAME='simsun'
NONEBOT_PLUGIN_GROUPMATE_WAIFU_FALLBACK_FONTS=["Arial", "Tahoma", "Microsoft YaHei"]
NONEBOT_PLUGIN_GROUPMATE_WAIFU_WAIFU_PATH='./data/waifu/'
NONEBOT_PLUGIN_GROUPMATE_WAIFU_WAIFU_RESET=True
NONEBOT_PLUGIN_GROUPMATE_WAIFU_AT_LISTEN=True
NONEBOT_PLUGIN_GROUPMATE_WAIFU_WAIFU_HE=40
NONEBOT_PLUGIN_GROUPMATE_WAIFU_WAIFU_BE=20
NONEBOT_PLUGIN_GROUPMATE_WAIFU_WAIFU_NTR=50
NONEBOT_PLUGIN_GROUPMATE_WAIFU_HAPPY_END_TIPS=["好耶~", "婚礼？启动！"]
NONEBOT_PLUGIN_GROUPMATE_WAIFU_BAD_END_TIPS=["你没有娶到群友，强者注定孤独，加油！", "找不到对象.jpg"]
NONEBOT_PLUGIN_GROUPMATE_WAIFU_WAIFU_LAST_SENT_TIME_FILTER=2592000
NONEBOT_PLUGIN_GROUPMATE_WAIFU_YINPA_HE=50
NONEBOT_PLUGIN_GROUPMATE_WAIFU_YINPA_CP=80
NONEBOT_PLUGIN_GROUPMATE_WAIFU_BG_IMAGE='./data/waifu/bg.png'
```

# 📞 联系

如有建议，bug 反馈等可以加群

机器人 bug 研究中心（闲聊群） 744751179

永恒之城（测试群） 724024810

![群号](https://github.com/KarisAya/clovers/blob/master/%E9%99%84%E4%BB%B6/qrcode_1676538742221.jpg)
